@@ -7,8 +7,6 @@
     EVENT_TYPE_ENTRY(APPLICATION_LAUNCHED) \
     EVENT_TYPE_ENTRY(APPLICATION_TERMINATED) \
     EVENT_TYPE_ENTRY(APPLICATION_FRONT_SWITCHED) \
-    EVENT_TYPE_ENTRY(APPLICATION_ACTIVATED) \
-    EVENT_TYPE_ENTRY(APPLICATION_DEACTIVATED) \
     EVENT_TYPE_ENTRY(APPLICATION_VISIBLE) \
     EVENT_TYPE_ENTRY(APPLICATION_HIDDEN) \
     EVENT_TYPE_ENTRY(WINDOW_CREATED) \
@@ -19,11 +17,6 @@
     EVENT_TYPE_ENTRY(WINDOW_MINIMIZED) \
     EVENT_TYPE_ENTRY(WINDOW_DEMINIMIZED) \
     EVENT_TYPE_ENTRY(WINDOW_TITLE_CHANGED) \
-    EVENT_TYPE_ENTRY(SLS_WINDOW_MOVED) \
-    EVENT_TYPE_ENTRY(SLS_WINDOW_RESIZED) \
-    EVENT_TYPE_ENTRY(SLS_WINDOW_ORDER_CHANGED) \
-    EVENT_TYPE_ENTRY(SLS_WINDOW_IS_VISIBLE) \
-    EVENT_TYPE_ENTRY(SLS_WINDOW_IS_INVISIBLE) \
     EVENT_TYPE_ENTRY(SLS_SPACE_ADD_WINDOW) \
     EVENT_TYPE_ENTRY(SLS_SPACE_REMOVE_WINDOW) \
     EVENT_TYPE_ENTRY(SLS_SPACE_CREATED) \
