@@ -8,6 +8,7 @@ extern CGError SLSReleaseConnection(int cid);
 extern CGError SLSRegisterConnectionNotifyProc(int cid, connection_callback *handler, uint32_t event, void *context);
 extern CGError SLSGetWindowBounds(int cid, uint32_t wid, CGRect *frame);
 extern CGError SLSGetWindowLevel(int cid, uint32_t wid, int *level);
+extern int SLSGetWindowSubLevel(int cid, uint32_t wid);
 extern CGError SLSGetWindowAlpha(int cid, uint32_t wid, float *alpha);
 extern CGError SLSSetWindowAlpha(int cid, uint32_t wid, float alpha);
 extern CGError SLSSetWindowResolution(int cid, uint32_t wid, double resolution);
@@ -27,6 +28,7 @@ extern CGError SLSSetWindowBackgroundBlurRadiusStyle(int cid, uint32_t wid, int
 extern CGError SLSOrderWindow(int cid, uint32_t wid, int mode, uint32_t rel_wid);
 extern CGError SLSWindowIsOrderedIn(int cid, uint32_t wid, uint8_t *value);
 extern CGError SLSSetWindowLevel(int cid, uint32_t wid, int level);
+extern CGError SLSSetWindowSubLevel(int cid, uint32_t wid, int sub_level);
 extern CGContextRef SLWindowContextCreate(int cid, uint32_t wid, CFDictionaryRef options);
 extern CGError CGSNewRegionWithRect(CGRect *rect, CFTypeRef *region);
 extern CFUUIDRef CGDisplayCreateUUIDFromDisplayID(uint32_t did);
@@ -37,6 +39,7 @@ extern CFStringRef SLSCopyBestManagedDisplayForPoint(int cid, CGPoint point);
 extern bool SLSManagedDisplayIsAnimating(int cid, CFStringRef uuid);
 extern CGError SLSGetMenuBarAutohideEnabled(int cid, int *enabled);
 extern CGError SLSGetRevealedMenuBarBounds(CGRect *rect, int cid, uint64_t sid);
+extern CGError SLSGetDisplayMenubarHeight(uint32_t did, uint32_t *height);
 extern CGError SLSGetDockRectWithReason(int cid, CGRect *rect, int *reason);
 extern Boolean CoreDockGetAutoHideEnabled(void);
 extern void CoreDockGetOrientationAndPinning(int *orientation, int *pinning);
@@ -54,12 +57,13 @@ extern CGError SLSMoveWindow(int cid, uint32_t wid, CGPoint *point);
 extern CFArrayRef SLSCopyAssociatedWindows(int cid, uint32_t wid);
 extern CFTypeRef SLSWindowQueryWindows(int cid, CFArrayRef windows, int count);
 extern CFTypeRef SLSWindowQueryResultCopyWindows(CFTypeRef window_query);
-extern CGError SLSWindowIteratorAdvance(CFTypeRef iterator);
+extern int SLSWindowIteratorGetCount(CFTypeRef iterator);
+extern bool SLSWindowIteratorAdvance(CFTypeRef iterator);
 extern uint32_t SLSWindowIteratorGetParentID(CFTypeRef iterator);
 extern uint32_t SLSWindowIteratorGetWindowID(CFTypeRef iterator);
 extern uint64_t SLSWindowIteratorGetTags(CFTypeRef iterator);
 extern uint64_t SLSWindowIteratorGetAttributes(CFTypeRef iterator);
-extern int SLSWindowIteratorGetLevel(CFTypeRef iterator);
+extern int SLSWindowIteratorGetLevel(CFTypeRef iterator, int32_t index);
 extern OSStatus _SLPSGetFrontProcess(ProcessSerialNumber *psn);
 extern CGError SLSGetWindowOwner(int cid, uint32_t wid, int *wcid);
 extern CGError SLSGetConnectionPSN(int cid, ProcessSerialNumber *psn);
@@ -73,7 +77,9 @@ extern CGError SLSWindowSetShadowProperties(uint32_t wid, CFDictionaryRef option
 extern CGError SLSRequestNotificationsForWindows(int cid, uint32_t *window_list, int window_count);
 extern CGError SLSSetWindowTransform(int cid, uint32_t wid, CGAffineTransform t);
 extern CFTypeRef SLSTransactionCreate(int cid);
-extern CGError SLSTransactionCommit(CFTypeRef transaction, int unknown);
+extern CGError SLSTransactionCommit(CFTypeRef transaction, int synchronous);
 extern CGError SLSTransactionSetWindowTransform(CFTypeRef transaction, uint32_t wid, int unknown, int unknown2, CGAffineTransform t);
 extern CGError SLSTransactionOrderWindow(CFTypeRef transaction, uint32_t wid, int order, uint32_t rel_wid);
+extern CGError SLSTransactionOrderWindowGroup(CFTypeRef transaction, uint32_t wid, int order, uint32_t rel_wid);
+extern CGError SLSTransactionSetWindowSystemAlpha(CFTypeRef transaction, uint32_t wid, float alpha);
 extern CFArrayRef SLSHWCaptureWindowList(int cid, uint32_t *window_list, int window_count, uint32_t options);
