@@ -39,7 +39,6 @@ struct window
     uint8_t rule_flags;
     uint8_t flags;
     float opacity;
-    struct border border;
 };
 
 enum window_flag
@@ -61,7 +60,6 @@ enum window_rule_flag
     WINDOW_RULE_FULLSCREEN = 1 << 1,
     WINDOW_RULE_MFF        = 1 << 2,
     WINDOW_RULE_MFF_VALUE  = 1 << 3,
-    WINDOW_RULE_BORDER     = 1 << 4,
 };
 
 #define window_rule_check_flag(w, x) ((w)->rule_flags  &  (x))
@@ -77,7 +75,7 @@ char *window_title_ts(struct window *window);
 CGPoint window_ax_origin(struct window *window);
 CGRect window_ax_frame(struct window *window);
 float window_opacity(struct window *window);
-int window_level(struct window *window);
+int window_level(uint32_t wid);
 uint64_t window_tags(struct window *window);
 CFStringRef window_role(struct window *window);
 char *window_role_ts(struct window *window);
@@ -91,7 +89,6 @@ bool window_is_undersized(struct window *window);
 bool window_is_minimized(struct window *window);
 bool window_is_fullscreen(struct window *window);
 bool window_is_sticky(struct window *window);
-bool window_is_topmost(struct window *window);
 bool window_is_standard(struct window *window);
 bool window_is_dialog(struct window *window);
 bool window_is_popover(struct window *window);
