@@ -1,6 +1,21 @@
 #ifndef WORKSPACE_H
 #define WORKSPACE_H
 
+#define SUPPORTED_MACOS_VERSION_LIST    \
+    SUPPORT_MACOS_VERSION(sonoma,   14) \
+    SUPPORT_MACOS_VERSION(ventura,  13) \
+    SUPPORT_MACOS_VERSION(monterey, 12) \
+    SUPPORT_MACOS_VERSION(bigsur,   11)
+
+#define SUPPORT_MACOS_VERSION(name, major_version) \
+static bool _workspace_is_macos_version_##name; \
+static inline bool workspace_is_macos_##name(void) \
+{ \
+    return _workspace_is_macos_version_##name; \
+}
+    SUPPORTED_MACOS_VERSION_LIST
+#undef SUPPORT_MACOS_VERSION
+
 @interface workspace_context : NSObject {
 }
 - (id)init;
@@ -15,9 +30,6 @@ void workspace_application_observe_finished_launching(void *context, struct proc
 void workspace_application_observe_activation_policy(void *context, struct process *process);
 int workspace_display_notch_height(uint32_t did);
 pid_t workspace_get_dock_pid(void);
-bool workspace_is_macos_ventura(void);
-bool workspace_is_macos_monterey(void);
-bool workspace_is_macos_bigsur(void);
 bool workspace_event_handler_begin(void **context);
 
 #endif
